/**
 *
 * Copyright 2005-2006 The Apache Software Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.nighttale.stomp;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

import javax.jms.JMSException;
import javax.jms.MapMessage;
import javax.jms.Message;
import javax.jms.MessageListener;
import javax.jms.TextMessage;

import org.apache.activemq.command.ActiveMQMapMessage;
import org.json.simple.JSONObject;
import org.json.simple.JSONValue;

/**
 * @author Dejan Bosanac <dejan@nighttale.net>
 *
 */
public class ClientReceiver implements MessageListener {

	public void onMessage(Message message) {
		try {
			Map data = new HashMap();
			if (message instanceof TextMessage) {
				String type = message.getStringProperty("amq-msg-type");
				if (type != null && type.equals("MapMessage")) {
					data = (JSONObject)JSONValue.parse(((TextMessage)message).getText());
				} else {
					throw new Exception("Not valid JSON message");
				}
			} else if (message instanceof MapMessage) {
				data = ((ActiveMQMapMessage)message).getContentMap();
			} else {
				throw new Exception(message.getClass() + " is not valid type for this que");
			}
			Iterator it = data.keySet().iterator();
			while (it.hasNext()) {
				Object key = it.next();
				Object value = data.get(key);
				System.out.println(key + "=" + value);
			}
		} catch (Throwable e) {
			//TODO handle errors
			e.printStackTrace();
		} finally {
			try{
				message.acknowledge();
			} catch (JMSException igonre) {}
		}
	}
}
